@@ -25,8 +25,11 @@
 #' @param key Your API key; loads from .Rprofile.
 #' @param return_id (logical) If TRUE (default), return the taxon id as well as the name
 #' and rank of taxa in the lineage returned.
+#' @param rows (numeric) Any number from 1 to inifity. If the default NA, all rows are
+#' considered. Note that this parameter is ignored if you pass in a taxonomic id instead
+#' of a name of class character.
 #'
-#' @return A named list of data.frames with the taxonomic classifcation of
+#' @return A named list of data.frames with the taxonomic classification of
 #'    every supplied taxa.
 #' @details If IDs are supplied directly (not from the \code{get_*} functions) you
 #' must specify the type of ID. There is a timeout of 1/3 seconds between
@@ -113,6 +116,12 @@
 #' ## the return_id parameter is logical, and you can turn it on or off. It's TRUE by default
 #' classification(c("Alopias vulpinus","Pinus sylvestris"), db = 'ncbi', return_id = TRUE)
 #' classification(c("Alopias vulpinus","Pinus sylvestris"), db = 'ncbi', return_id = FALSE)
+#'
+#' # Use rows parameter to select certain
+#' classification('Poa annua', db = 'tropicos')
+#' classification('Poa annua', db = 'tropicos', rows=1:4)
+#' classification('Poa annua', db = 'tropicos', rows=1)
+#' classification('Poa annua', db = 'tropicos', rows=6)
 #' }
 #'
 #' @examples \dontrun{
@@ -125,35 +134,35 @@ classification <- function(...){
 
 #' @export
 #' @rdname classification
-classification.default <- function(x, db = NULL, callopts=list(), return_id = TRUE, ...){
+classification.default <- function(x, db = NULL, callopts=list(), return_id = TRUE, rows = NA, ...){
   nstop(db)
   switch(db,
          itis = {
-           id <- process_ids(x, get_tsn, ...)
+           id <- process_ids(x, get_tsn, rows = rows, ...)
            setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
          },
          ncbi = {
-           id <- process_ids(x, get_uid, ...)
-           setNames(classification(id, return_id=return_id, ...), x)
+           id <- process_ids(x, get_uid, rows = rows, ...)
+           setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
          },
          eol = {
-           id <- process_ids(x, get_eolid, ...)
+           id <- process_ids(x, get_eolid, rows = rows, ...)
            setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
          },
          col = {
-           id <- process_ids(x, get_colid, ...)
-           setNames(classification(id, return_id=return_id, ...), x)
+           id <- process_ids(x, get_colid, rows = rows, ...)
+           setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
          },
          tropicos = {
-           id <- process_ids(x, get_tpsid, ...)
+           id <- process_ids(x, get_tpsid, rows = rows, ...)
            setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
          },
          gbif = {
-           id <- process_ids(x, get_gbifid, ...)
+           id <- process_ids(x, get_gbifid, rows = rows, ...)
            setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
          },
          nbn = {
-           id <- process_ids(x, get_nbnid, ...)
+           id <- process_ids(x, get_nbnid, rows = rows, ...)
            setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
          },
          stop("the provided db value was not recognised", call.=FALSE)
@@ -173,14 +182,13 @@ process_ids <- function(input, fxn, ...){
 
 #' @export
 #' @rdname classification
-classification.tsn <- function(id, callopts = list(), return_id = TRUE, ...)
-{
-  fun <- function(x){
+classification.tsn <- function(id, callopts = list(), return_id = TRUE, ...) {
+  fun <- function(x, callopts){
     # return NA if NA is supplied
     if (is.na(x)) {
       out <- NA
     } else {
-      out <- getfullhierarchyfromtsn(x, curlopts = callopts, ...)
+      out <- getfullhierarchyfromtsn(x, callopts, ...)
       # remove overhang
       out <- out[1:which(out$tsn == x), c('taxonName', 'rankName', 'tsn')]
       names(out) <- c('name', 'rank', 'id')
@@ -189,23 +197,24 @@ classification.tsn <- function(id, callopts = list(), return_id = TRUE, ...)
       return(out)
     }
   }
-  out <- lapply(id, fun)
+  out <- lapply(id, fun, callopts = callopts)
   names(out) <- id
-  structure(out, class='classification', db='itis')
+  structure(out, class = 'classification', db = 'itis')
 }
 
 #' @export
 #' @rdname classification
-classification.uid <- function(id, return_id = TRUE, ...) {
-  fun <- function(x){
+classification.uid <- function(id, callopts = list(), return_id = TRUE, ...) {
+  fun <- function(x, callopts){
     # return NA if NA is supplied
-    if(is.na(x)){
+    if (is.na(x)) {
       out <- NA
     } else {
       baseurl <- "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi?db=taxonomy"
       ID <- paste("ID=", x, sep = "")
       searchurl <- paste(baseurl, ID, sep = "&")
-      tt <- getURL(searchurl)
+      # tt <- getURL(searchurl)
+      tt <- GET(searchurl, callopts)
       ttp <- xmlTreeParse(tt, useInternalNodes = TRUE)
       out <- data.frame(name = xpathSApply(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/ScientificName", xmlValue),
                         rank = xpathSApply(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/Rank", xmlValue),
@@ -222,9 +231,9 @@ classification.uid <- function(id, return_id = TRUE, ...) {
     Sys.sleep(0.33)
     return(out)
   }
-  out <- lapply(id, fun)
+  out <- lapply(id, fun, callopts = callopts)
   names(out) <- id
-  structure(out, class='classification', db='ncbi')
+  structure(out, class = 'classification', db = 'ncbi')
 }
 
 #' @export
@@ -235,7 +244,7 @@ classification.eolid <- function(id, key = NULL, callopts = list(), return_id =
     if(is.na(x)){
       out <- NA
     } else {
-      url = 'http://www.eol.org/api/hierarchy_entries/1.0/'
+      url = 'http://eol.org/api/hierarchy_entries/1.0/'
       key <- getkey(key, "eolApiKey")
       urlget <- paste(url, x, '.json', sep="")
       args <- compact(list(common_names=common_names, synonyms=synonyms))
@@ -263,8 +272,8 @@ classification.eolid <- function(id, key = NULL, callopts = list(), return_id =
 
 #' @export
 #' @rdname classification
-classification.colid <- function(id, start = NULL, checklist = NULL, return_id = TRUE, ...) {
-  fun <- function(x){
+classification.colid <- function(id, start = NULL, checklist = NULL, callopts = list(), return_id = TRUE, ...) {
+  fun <- function(x, callopts){
     # return NA if NA is supplied
     if(is.na(x)){
       out <- NA
@@ -281,8 +290,9 @@ classification.colid <- function(id, start = NULL, checklist = NULL, return_id =
       }
 
       args <- compact(list(id = x, response = "full", start = start))
-      out <- getForm(url, .params = args)
-      tt <- xmlParse(out)
+      out <- GET(url, query = args, callopts)
+      stop_for_status(out)
+      tt <- xmlParse(content(out, "text"))
 
       out <- data.frame(name = xpathSApply(tt, "//classification//name", xmlValue),
                         rank = xpathSApply(tt, "//classification//rank", xmlValue),
@@ -297,15 +307,15 @@ classification.colid <- function(id, start = NULL, checklist = NULL, return_id =
     }
     return(out)
   }
-  out <- lapply(id, fun)
+  out <- lapply(id, fun, callopts = callopts)
   names(out) <- id
-  structure(out, class='classification', db='col')
+  structure(out, class = 'classification', db = 'col')
 }
 
 #' @export
 #' @rdname classification
 classification.tpsid <- function(id, key = NULL, callopts = list(), return_id = TRUE, ...) {
-  fun <- function(x){
+  fun <- function(x, callopts){
     if(is.na(x)) {
       out <- NA
     } else {
@@ -326,7 +336,7 @@ classification.tpsid <- function(id, key = NULL, callopts = list(), return_id =
     }
     return(out)
   }
-  out <- lapply(id, fun)
+  out <- lapply(id, fun, callopts = callopts)
   names(out) <- id
   structure(out, class='classification', db='tropicos')
 }
@@ -334,11 +344,11 @@ classification.tpsid <- function(id, key = NULL, callopts = list(), return_id =
 #' @export
 #' @rdname classification
 classification.gbifid <- function(id, callopts = list(), return_id = TRUE, ...) {
-  fun <- function(x){
+  fun <- function(x, callopts){
     if(is.na(x)) {
       out <- NA
     } else {
-      out <- suppressWarnings(tryCatch(gbif_name_usage(key = x), error=function(e) e))
+      out <- suppressWarnings(tryCatch(gbif_name_usage(key = x, callopts = callopts), error=function(e) e))
       if(is(out, "simpleError")){ NA } else {
         nms <- ldply(out[c('kingdom','phylum','class','order','family','genus','species')])
         keys <- unname(unlist(out[paste0(c('kingdom','phylum','class','order','family','genus','species'), "Key")]))
@@ -349,20 +359,20 @@ classification.gbifid <- function(id, callopts = list(), return_id = TRUE, ...)
       }
     }
   }
-  out <- lapply(id, fun)
+  out <- lapply(id, fun, callopts = callopts)
   names(out) <- id
-  structure(out, class='classification', db='gbif')
+  structure(out, class = 'classification', db = 'gbif')
 }
 
 #' @export
 #' @rdname classification
 classification.nbnid <- function(id, callopts = list(), return_id = TRUE, ...) {
-  fun <- function(x){
-    if(is.na(x)) {
+  fun <- function(x, callopts){
+    if (is.na(x)) {
       out <- NA
     } else {
-      out <- suppressWarnings(tryCatch(nbn_classifcation(id=x, ...), error=function(e) e))
-      if(is(out, "simpleError")){ NA } else {
+      out <- suppressWarnings(tryCatch(nbn_classification(id=x, callopts), error=function(e) e))
+      if (is(out, "simpleError")){ NA } else {
         out <- out[ , c('name','rank', 'taxonVersionKey')]
         names(out) <- c('name', 'rank', 'id')
         # Optionally return id of lineage
@@ -371,9 +381,9 @@ classification.nbnid <- function(id, callopts = list(), return_id = TRUE, ...) {
       }
     }
   }
-  out <- lapply(id, fun)
+  out <- lapply(id, fun, callopts = callopts)
   names(out) <- id
-  structure(out, class='classification', db='nbn')
+  structure(out, class = 'classification', db = 'nbn')
 }
 
 #' @export
