@@ -1,10 +1,9 @@
 #' Return all accepted names for a taxon name with a given id.
 #'
-#' @import httr plyr jsonlite
 #' @export
 #' @param id the taxon identifier code
 #' @param key Your Tropicos API key; loads from .Rprofile.
-#' @param callopts Further args passed on to httr::GET
+#' @param ... Curl options passed on to \code{\link[httr]{GET}}
 #' @return List or dataframe.
 #' @examples \dontrun{
 #' tp_accnames(id = 25503923)
@@ -14,22 +13,23 @@
 #' tp_accnames(id = 25509881)
 #' }
 
-tp_accnames <- function(id, key = NULL, callopts=list())
-{
+tp_accnames <- function(id, key = NULL, ...) {
   url = sprintf('http://services.tropicos.org/Name/%s/AcceptedNames', id)
 	key <- getkey(key, "tropicosApiKey")
   args <- taxize_compact(list(apikey = key, format = 'json'))
-  tmp <- GET(url, query=args, callopts)
+  tmp <- GET(url, query = args, ...)
   stop_for_status(tmp)
   tmp2 <- content(tmp, as = "text")
   res <- jsonlite::fromJSON(tmp2, FALSE)
 
-  if("Error" %in% names(res[[1]])){ res[[1]] } else {
+  if ("Error" %in% names(res[[1]])) {
+    res[[1]]
+  } else {
     vvv <- lapply(res, getdata)
     syns <- do.call(rbind.fill, lapply(vvv, "[[", "syn"))
     accs <- do.call(rbind.fill, lapply(vvv, "[[", "acc"))
     refs <- do.call(rbind.fill, lapply(vvv, "[[", "ref"))
-    list(synonyms=syns, acceptednames=accs, reference=refs)
+    list(synonyms = syns, acceptednames = accs, reference = refs)
   }
 }
 
@@ -40,7 +40,7 @@ getdata <- function(x) {
   names(acc) <- tolower(names(acc))
   ref <- data.frame(x$Reference, stringsAsFactors = FALSE)
   names(ref) <- tolower(names(ref))
-  list(syn=syn, acc=acc, ref=ref)
+  list(syn = syn, acc = acc, ref = ref)
 }
 
 # getdata <- function(x) {
@@ -66,7 +66,6 @@ getdata <- function(x) {
 #' @export
 #' @keywords internal
 #' @rdname tp_acceptednames-deprecated
-tp_acceptednames <- function(id, format = 'json', output = 'df', key = NULL)
-{
+tp_acceptednames <- function(id, format = 'json', output = 'df', key = NULL) {
   .Deprecated("tp_accnames", "taxize", "Function name changed. See tp_accnames", "tp_acceptednames")
 }
