@@ -1,19 +1,19 @@
 #' Search uBio by namebank ID.
-#' 
+#'
 #' @import httr XML RCurl
 #' @export
 #' @param namebankID (character) uBio namebank ID
-#' @param keyCode Your uBio API key; loads from .Rprofile. If you don't have 
+#' @param keyCode Your uBio API key; loads from .Rprofile. If you don't have
 #'    one, obtain one at http://www.ubio.org/index.php?pagename=form.
 #' @param callopts Parameters passed on to httr::GET call.
-#' @return A list of four data.frame's, one for the name itself, one for synonyms, 
+#' @return A list of four data.frame's, one for the name itself, one for synonyms,
 #' one for vernacular names, and one for citations.
-#' @examples \donttest{
+#' @examples \dontrun{
 #' ubio_id(namebankID = 2483153)
 #' ubio_id(namebankID = 105509)
 #' ubio_id(namebankID = 2843601)
 #' ubio_id(namebankID = 2478181)
-#' 
+#'
 #' # Pass in curl options
 #' library("httr")
 #' ubio_id(namebankID = 2478181, callopts=verbose())
@@ -29,27 +29,31 @@ ubio_id <- function(namebankID = NULL, keyCode = NULL, callopts=list())
   tmp <- GET(url, query=args, callopts)
   stop_for_status(tmp)
   tt <- content(tmp)
-  
-  toget <- c("namebankID", "nameString", "fullNameString", "packageID", 
+
+  toget <- c("namebankID", "nameString", "fullNameString", "packageID",
              "packageName", "basionymUnit", "rankID", "rankName")
   temp <- lapply(toget, function(x) sapply(xpathApply(tt, paste("/results/", x, sep="")), xmlValue))
-  temp[2:3] <- sapply(temp[2:3], base64Decode)
+  temp[2:3] <- sapply(temp[2:3], function(x){
+    trybase64 <- tryCatch(base64Decode(x), error=function(e) e)
+    if( is(trybase64, "error") ) "" else x
+  })
   out <- data.frame(do.call(cbind, temp), stringsAsFactors = FALSE)
-  names(out) <- c("namebankID", "nameString", "fullNameString", "packageID", 
+  names(out) <- c("namebankID", "nameString", "fullNameString", "packageID",
                   "packageName", "basionymUnit", "rankID", "rankName")
   out <- tolowerfxn(out)
-  
+  out <- if(all(temp == "")) NULL else out
+
   # check for existence
-  if(length(xpathApply(tt, "//homotypicSynonyms")) == 0) { syns <- NULL } else {  
+  if(length(xpathApply(tt, "//homotypicSynonyms")) == 0) { syns <- NULL } else {
     syns <- getxmldata(obj=tt, node="homotypicSynonyms", todecode=2:3)
     syns <- tolowerfxn(taxize_ldfast(syns, convertvec=TRUE))
   }
-  
-  if(length(xpathApply(tt, "//vernacularNames")) == 0) { verns <- NULL } else {  
+
+  if(length(xpathApply(tt, "//vernacularNames")) == 0) { verns <- NULL } else {
     verns <- getxmldata(obj=tt, node="vernacularNames", todecode=2)
     verns <- tolowerfxn(taxize_ldfast(verns, convertvec=TRUE))
   }
-  
+
   if(length(xpathApply(tt, "//results//mappings")) == 0 && length(xpathApply(tt, "//results//citations")) == 0) { mappings <- cites <- NULL } else {
     checkmapping <- xpathApply(tt, "//results//mappings")
     if(length(checkmapping) == 0){
@@ -62,7 +66,7 @@ ubio_id <- function(namebankID = NULL, keyCode = NULL, callopts=list())
       cites <- NULL
     }
   }
-  
+
   list(data=out, synonyms=syns, vernaculars=verns, cites=cites, mappings=mappings)
 }
 
@@ -82,4 +86,4 @@ tolowerfxn <- function(x){
     names(x) <- tolower(names(x))
     return( x )
   }
-}
\ No newline at end of file
+}
