@@ -3,11 +3,6 @@ context("eol_dataobjects")
 
 temp <- eol_dataobjects(id="d72801627bf4adf1a38d9c5f10cc767f", verbose=FALSE)
 
-test_that("eol_dataobjects returns the correct dimensions", {
-	expect_equal(length(temp), 8)
-	expect_equal(NCOL(temp$dataObjects), 22)
-})
-
 test_that("eol_dataobjects returns the correct class", {
 	expect_is(temp, "list")
 	expect_is(temp$scientificName, "character")
