@@ -11,6 +11,6 @@ test_that("tp_search returns the correct class", {
 
 test_that("tp_search returns a data.frame with one raw starting none found", {
   expect_that(uuu, is_a("data.frame"))
-  expect_that(names(uuu), equals("Error"))
+  expect_that(names(uuu), equals("error"))
   expect_that(as.character(uuu[1,1]), equals("No names were found"))
 })
